@@ -16,6 +16,10 @@ logger = getLogger(__name__)
 
 
 class StageCallback(Protocol):
+    """
+    Definition for a stage job function.
+    """
+
     def __call__(
         self,
         job: WorkerContext,
@@ -25,6 +29,9 @@ class StageCallback(Protocol):
         source: Image.Image,
         **kwargs: Any
     ) -> Image.Image:
+        """
+        Run this stage against a source image.
+        """
         pass
 
 
@@ -104,7 +111,7 @@ class ChainPipeline:
             kwargs = stage_kwargs or {}
             kwargs = {**pipeline_kwargs, **kwargs}
 
-            logger.info(
+            logger.debug(
                 "running stage %s on image with dimensions %sx%s, %s",
                 name,
                 image.width,
@@ -145,7 +152,7 @@ class ChainPipeline:
                     [stage_tile],
                 )
             else:
-                logger.info("image within tile size, running stage")
+                logger.debug("image within tile size, running stage")
                 image = stage_pipe(
                     job,
                     server,
@@ -156,7 +163,7 @@ class ChainPipeline:
                     **kwargs
                 )
 
-            logger.info(
+            logger.debug(
                 "finished stage %s, result size: %sx%s", name, image.width, image.height
             )
 
