@@ -2,24 +2,27 @@ from logging import getLogger
 
 from PIL import Image
 
-from ..device_pool import JobContext
 from ..output import save_image
 from ..params import ImageParams, StageParams
-from ..utils import ServerContext
+from ..server import ServerContext
+from ..worker import WorkerContext
 
 logger = getLogger(__name__)
 
 
 def persist_disk(
-    _job: JobContext,
+    _job: WorkerContext,
     server: ServerContext,
     _stage: StageParams,
     _params: ImageParams,
-    source_image: Image.Image,
+    source: Image.Image,
     *,
     output: str,
+    stage_source: Image.Image,
     **kwargs,
 ) -> Image.Image:
-    dest = save_image(server, output, source_image)
+    source = stage_source or source
+
+    dest = save_image(server, output, source)
     logger.info("saved image to %s", dest)
-    return source_image
+    return source
