@@ -9,7 +9,14 @@ logger = getLogger(__name__)
 
 
 class TileCallback(Protocol):
+    """
+    Definition for a tile job function.
+    """
+
     def __call__(self, image: Image.Image, dims: Tuple[int, int, int]) -> Image.Image:
+        """
+        Run this stage against a single tile.
+        """
         pass
 
 
@@ -32,7 +39,7 @@ def process_tile_grid(
             idx = (y * tiles_x) + x
             left = x * tile
             top = y * tile
-            logger.info("processing tile %s of %s, %s.%s", idx + 1, total, y, x)
+            logger.debug("processing tile %s of %s, %s.%s", idx + 1, total, y, x)
             tile_image = source.crop((left, top, left + tile, top + tile))
 
             for filter in filters:
@@ -80,7 +87,7 @@ def process_tile_spiral(
         top = center_y + int(top)
 
         counter += 1
-        logger.info("processing tile %s of %s, %sx%s", counter, len(tiles), left, top)
+        logger.debug("processing tile %s of %s, %sx%s", counter, len(tiles), left, top)
 
         # TODO: only valid for scale == 1, resize source for others
         tile_image = image.crop((left, top, left + tile, top + tile))
