@@ -121,7 +121,7 @@ def merge(a, b, path=None):
             elif a[key] == b[key]:
                 pass  # same leaf value
             else:
-                raise Exception("Conflict at %s" % ".".join(path + [str(key)]))
+                raise ValueError("conflict at %s" % ".".join(path + [str(key)]))
         else:
             a[key] = b[key]
     return a
